@@ -177,12 +177,11 @@ void RIG_FT1000MP::init_cmd()
 
 void RIG_FT1000MP::initialize()
 {
-	init_cmd();
-	cmd[4] = 0x81; // switch antenna tuner on
-	sendCommand(cmd,0);
-LOG_INFO("%s", str2hex(cmd.c_str(), 5));
+//	init_cmd();
+//	cmd[4] = 0x81; // switch antenna tuner on
+//	sendCommand(cmd,0);
+//LOG_DEBUG("%s", str2hex(cmd.c_str(), 5));
 //	selectA();
-
 }
 
 /*
@@ -275,7 +274,7 @@ RTTY-U : 00000101 10010001
 250    : 01000100
 */
 /*
-const std::string LSBstr   = { '\x08', '\x00', '\x57', '\x71', '\x00', '\x00', '\x00', '\x00', '\x11', '\x00', '\x11', '\x01', '\x81', '\x81', '\x11', '\x0A', '\x08', '\x00', '\x57', '\x72', '\x60', '\x00', '\x00', '\x00', '\x30', '\x00', '\x30', '\x91', '\x11', '\x11', '\x11', '\x48' };
+const std::string LSBstr   = { '\x08', '\x00', '\x15', '\xBE', '\x68', '\x00', '\x00', '\x00', '\x11', '\x00', '\x11', '\x01', '\x81', '\x81', '\x11', '\x0A', '\x08', '\x00', '\x57', '\x72', '\x60', '\x00', '\x00', '\x00', '\x30', '\x00', '\x30', '\x91', '\x11', '\x11', '\x11', '\x48' };
 const std::string USBstr   = { '\x08', '\x00', '\x57', '\x71', '\x00', '\x00', '\x00', '\x01', '\x11', '\x00', '\x11', '\x01', '\x81', '\x81', '\x11', '\x0A', '\x08', '\x00', '\x57', '\x72', '\x60', '\x00', '\x00', '\x00', '\x30', '\x00', '\x30', '\x91', '\x11', '\x11', '\x11', '\x48' };
 const std::string CWUstr   = { '\x08', '\x00', '\x57', '\x71', '\x00', '\x00', '\x00', '\x02', '\x11', '\x00', '\x11', '\x01', '\x81', '\x81', '\x11', '\x0A', '\x08', '\x00', '\x57', '\x72', '\x60', '\x00', '\x00', '\x00', '\x30', '\x00', '\x30', '\x91', '\x11', '\x11', '\x11', '\x48' };
 const std::string CWLstr   = { '\x08', '\x00', '\x57', '\x71', '\x00', '\x00', '\x00', '\x02', '\x91', '\x00', '\x11', '\x01', '\x81', '\x81', '\x11', '\x0A', '\x08', '\x00', '\x57', '\x72', '\x60', '\x00', '\x00', '\x00', '\x30', '\x00', '\x30', '\x91', '\x11', '\x11', '\x11', '\x48' };
@@ -290,32 +289,52 @@ const std::string PKUstr   = { '\x08', '\x00', '\x57', '\x71', '\x00', '\x00', '
 const std::string PKFstr   = { '\x08', '\x00', '\x57', '\x71', '\x00', '\x00', '\x00', '\x06', '\x91', '\x00', '\x11', '\x01', '\x81', '\x81', '\x11', '\x0A', '\x08', '\x00', '\x57', '\x72', '\x60', '\x00', '\x00', '\x00', '\x30', '\x00', '\x30', '\x91', '\x11', '\x11', '\x11', '\x48' };
 const std::string BOGUSstr = { '\x08', '\x00', '\x57', '\x71', '\x00', '\x00', '\x00', '\x24', '\x99', '\x00', '\x11', '\x01', '\x81', '\x81', '\x11', '\x0A', '\x08', '\x00', '\x57', '\x72', '\x60', '\x00', '\x00', '\x00', '\x30', '\x00', '\x30', '\x91', '\x11', '\x11', '\x11', '\x48' };
 
-const unsigned char data1[] = {
+const std::string data1 = {
 0x08, 0x00, 0x57, 0x71, 0x00, 0x00, 0x00, 0x00, 0x43, 0x00, 0x00, 0x01, 0x81, 0x81, 0x11, 0x0A,
 0x08, 0x00, 0x57, 0x72, 0x60, 0x00, 0x00, 0x00, 0x30, 0x00, 0x30, 0x91, 0x11, 0x11, 0x11, 0x48
 };
-const unsigned char data2[] = {
+const std::string data2[] = {
 0x08, 0x00, 0x57, 0x71, 0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x01, 0x81, 0x81, 0x11, 0x0A,
 0x08, 0x00, 0x57, 0x72, 0x60, 0x00, 0x00, 0x00, 0x30, 0x00, 0x30, 0x91, 0x11, 0x11, 0x11, 0x48
 };
-const unsigned char data3[] = {
+const std::string data3[] = {
 0x08, 0x00, 0x57, 0x71, 0x00, 0x00, 0x00, 0x00, 0x33, 0x00, 0x00, 0x01, 0x81, 0x81, 0x11, 0x0A,
 0x08, 0x00, 0x57, 0x72, 0x60, 0x00, 0x00, 0x03, 0xB0, 0x00, 0x30, 0x91, 0x11, 0x11, 0x11, 0x48
 };
-const unsigned char amsync[] = {
+const std::string amsync[] = {
 0x08, 0x00, 0x57, 0x67, 0x01, 0x00, 0x00, 0x03, 0x80, 0x00, 0x11, 0x11, 0x91, 0x91, 0x11, 0x08,
 0x08, 0x00, 0x57, 0x67, 0x02, 0x00, 0x00, 0x01, 0x11, 0x00, 0x11, 0x91, 0x11, 0x11, 0x11, 0xFA
 };
 */
 
+/*
+ * Ken Rawlings tests
+  
+ Band     Radio             Flrig                Fldigi
+160m     1.840.00       29449.08       29.440.080
+  80m    3.547.92       56776.72        56766.720
+  40m    7.036.00      112576.00       112576.000
+  30m   10.113.25      161812.06       161812.060  
+  20m   14.052.16      224834.60       224834.600
+  17m   18.076.25      289220.12       289220.120
+  15m   21.009.30      336148.94       336148.940
+  12m   24.900.00      398400.00       398400.000
+  10m   28.072.10      449153.64       449153.640
+  10m   29.099.40      465590.40       465590.400 
+
+08 00 55 73 04 00 00 06 11 00 11 B3 33
+0B 00 AA E6 0A 00 00 02 B3 00 11 B4 11
+11 01 55 CC 02 00 00 02 B3 00 22 33 11
+  
+*/
+ 
 bool RIG_FT1000MP::check()
 {
-//	return true;
 	init_cmd();
 	cmd[3] = 0x03;
 	cmd[4] = 0x10;
 
-	get_trace(1, "check");
+	getr("check");
 	int ret = waitN(32, 100, "check", ASC);
 	geth();
 
@@ -329,39 +348,20 @@ bool RIG_FT1000MP::get_info(void)
 {
 	int ret = 0;
 	int md = 0;
+
 	init_cmd();
 	cmd[3] = 0x03;  // read both vfo's
 	cmd[4] = 0x10;
-/*
-switch (tmd) {
-	default:
-	case 0: replystr = LSBstr; break;
-	case 1: replystr = USBstr; break;
-	case 2: replystr = CWUstr; break;
-	case 3: replystr = CWLstr; break;
-	case 4: replystr = AMIstr; break;
-	case 5: replystr = AMSstr; break;
-	case 6: replystr = FMstr; break;
-	case 7: replystr = FMWstr; break;
-	case 8: replystr = RTTYLstr; break;
-	case 9: replystr = RTTYUstr; break;
-	case 10: replystr = PKLstr; break;
-	case 11: replystr = PKUstr; break;
-	case 12: replystr = PKFstr; break;
-	case 13: replystr = BOGUSstr; break;
-}
-std::cout << "set " << FT1000MP_modes[tmd];
-if (++tmd == 13) tmd = 0;
-ret = replystr.length();
-*/
+	getr("get info");
 	ret = waitN(32, 100, "get info", ASC);
-	getthex("info");
+	geth();
+
 	std::string p;
 	if (ret >= 32) {
 		p = replystr.substr(replystr.length() - 32);
 
 		// vfo A data string
-		A.freq = ((((((p[1]<<8) + p[2])<<8) + p[3])<<8) + p[4])*10/16;
+		A.freq = (((((((p[1] & 0x7F)<<8 + (p[2] & 0xFF))<<8) + (p[3] & 0xFF))<<8) + (p[4] & 0xF0)) >> 4) * 10;
 
 		for (md = 0; md < 14; md++) {
 			if ( ((FT1000MP_mode[md].a & 0xFF) == (p[7] & 0xFF)) &&
@@ -370,13 +370,13 @@ ret = replystr.length();
 		}
 		if (md == 13) md = 0;
 		A.imode = md;
-std::cout << ", get " << FT1000MP_modes[A.imode] << std::endl;
 
 		A.iBW = 5*((p[8] & 0x70) >> 4) + (p[8] & 0x07);
 		if (A.iBW > 24) A.iBW = 24;
 
-		p += 16; // vfo B data string
-		B.freq = ((((((p[1]<<8) + p[2])<<8) + p[3])<<8) + p[4])*10/16;
+		p.erase(0,16);; // vfo B data string
+
+		B.freq = (((((((p[1] & 0x7F)<<8 + (p[2] & 0xFF))<<8) + (p[3] & 0xFF))<<8) + (p[4] & 0xF0)) >> 4) * 10;
 
 		for (md = 0; md < 14; md++) {
 			if ( ((FT1000MP_mode[md].a & 0xFF) == (p[7] & 0xFF)) &&
@@ -396,11 +396,13 @@ std::cout << ", get " << FT1000MP_modes[A.imode] << std::endl;
 
 unsigned long int RIG_FT1000MP::get_vfoA ()
 {
+	get_info();
 	return A.freq;
 }
 
 unsigned long int RIG_FT1000MP::get_vfoB ()
 {
+	get_info();
 	return B.freq;
 }
 
@@ -414,8 +416,10 @@ void RIG_FT1000MP::set_vfoA (unsigned long int freq)
 		cmd[i] |= (unsigned char)((freq % 10) * 16); freq /= 10;
 	}
 	cmd[4] = 0x0A;
+	setr("set vfo A");
 	sendCommand(cmd, 0);
-LOG_INFO("%s", str2hex(cmd.c_str(), cmd.length()));
+	seth();
+LOG_DEBUG("%s", str2hex(cmd.c_str(), cmd.length()));
 }
 
 void RIG_FT1000MP::set_vfoB (unsigned long int freq)
@@ -428,8 +432,10 @@ void RIG_FT1000MP::set_vfoB (unsigned long int freq)
 		cmd[i] |= (unsigned char)((freq % 10) * 16); freq /= 10;
 	}
 	cmd[4] = 0x8A;
+	setr("set vfo B");
 	sendCommand(cmd, 0);
-LOG_INFO("%s", str2hex(cmd.c_str(), cmd.length()));
+	seth();
+LOG_DEBUG("%s", str2hex(cmd.c_str(), cmd.length()));
 }
 
 int RIG_FT1000MP::get_modeA()
@@ -449,8 +455,10 @@ void RIG_FT1000MP::set_modeA(int val)
 	cmd[3] = val;
 	if (val > 6) cmd[3]++;
 	cmd[4] = 0x0C;
+	setr("set mode A");
 	sendCommand(cmd, 0);
-LOG_INFO("%s, %s", FT1000MP_modes[A.imode], str2hex(cmd.c_str(),5));
+	seth();
+LOG_DEBUG("%s, %s", FT1000MP_modes[A.imode], str2hex(cmd.c_str(),5));
 	get_info();
 }
 
@@ -461,8 +469,10 @@ void RIG_FT1000MP::set_modeB(int val)
 	cmd[3] = val;
 	if (val > 6) cmd[3]++;
 	cmd[4] = 0x0C;
+	setr("set mode B");
 	sendCommand(cmd, 0);
-LOG_INFO("%s, %s", FT1000MP_modes[B.imode], str2hex(cmd.c_str(),5));
+	seth();
+LOG_DEBUG("%s, %s", FT1000MP_modes[B.imode], str2hex(cmd.c_str(),5));
 	get_info();
 }
 
@@ -493,12 +503,16 @@ void RIG_FT1000MP::set_bwA(int val)
 	cmd[0] = 0x01; // 1st IF
 	cmd[3] = first_if;
 	cmd[4] = 0x8C;
+	setr("set bw A 1st IF");
 	sendCommand(cmd, 0);
-LOG_INFO("%s, %s", FT1000MP_widths[A.iBW], str2hex(cmd.c_str(), 5));
+	seth();
+LOG_DEBUG("%s, %s", FT1000MP_widths[A.iBW], str2hex(cmd.c_str(), 5));
 	cmd[0] = 0x02; // 2nd IF
 	cmd[3] = second_if;
+	setr("set bw A 2nd IF");
 	sendCommand(cmd, 0);
-LOG_INFO("%s, %s", FT1000MP_widths[A.iBW], str2hex(cmd.c_str(), 5));
+	seth();
+LOG_DEBUG("%s, %s", FT1000MP_widths[A.iBW], str2hex(cmd.c_str(), 5));
 }
 
 int RIG_FT1000MP::get_bwB()
@@ -522,12 +536,16 @@ void RIG_FT1000MP::set_bwB(int val)
 	cmd[0] = 0x01; // 1st IF
 	cmd[3] = first_if;
 	cmd[4] = 0x8C;
+	setr("set bw B 1st IF");
 	sendCommand(cmd, 0);
-LOG_INFO("%s, %s", FT1000MP_widths[B.iBW], str2hex(cmd.c_str(), 5));
+	seth();
+LOG_DEBUG("%s, %s", FT1000MP_widths[B.iBW], str2hex(cmd.c_str(), 5));
 	cmd[0] = 0x02; // 2nd IF
 	cmd[3] = second_if;
+	setr("set bw B 2nd IF");
 	sendCommand(cmd, 0);
-LOG_INFO("%s, %s", FT1000MP_widths[B.iBW], str2hex(cmd.c_str(), 5));
+	seth();
+LOG_DEBUG("%s, %s", FT1000MP_widths[B.iBW], str2hex(cmd.c_str(), 5));
 }
 
 int  RIG_FT1000MP::def_bandwidth(int m)
@@ -544,8 +562,10 @@ void RIG_FT1000MP::selectA()
 {
 	init_cmd();
 	cmd[4] = 0x05;
+	setr("select A");
 	sendCommand(cmd, 0);
-LOG_INFO("%s", str2hex(cmd.c_str(), 5));
+	seth();
+LOG_DEBUG("%s", str2hex(cmd.c_str(), 5));
 }
 
 void RIG_FT1000MP::selectB()
@@ -553,8 +573,10 @@ void RIG_FT1000MP::selectB()
 	init_cmd();
 	cmd[3] = 0x01;
 	cmd[4] = 0x05;
+	setr("select B");
 	sendCommand(cmd, 0);
-LOG_INFO("%s", str2hex(cmd.c_str(), 5));
+	seth();
+LOG_DEBUG("%s", str2hex(cmd.c_str(), 5));
 }
 
 void RIG_FT1000MP::set_split(bool val)
@@ -563,8 +585,10 @@ void RIG_FT1000MP::set_split(bool val)
 	init_cmd();
 	cmd[3] = val ? 0x01 : 0x00;
 	cmd[4] = 0x01;
+	setr("set split");
 	sendCommand(cmd, 0);
-LOG_INFO("%s", str2hex(cmd.c_str(), 5));
+	seth();
+LOG_DEBUG("%s", str2hex(cmd.c_str(), 5));
 }
 
 
@@ -575,8 +599,10 @@ void RIG_FT1000MP::set_PTT_control(int val)
 	if (val) cmd[3] = 1;
 	else	 cmd[3] = 0;
 	cmd[4] = 0x0F;
+	setr("set PTT");
 	sendCommand(cmd, 0);
-LOG_INFO("%s", str2hex(cmd.c_str(), 5));
+	seth();
+LOG_DEBUG("%s", str2hex(cmd.c_str(), 5));
 	ptt_ = val;
 }
 
@@ -584,8 +610,10 @@ void RIG_FT1000MP::tune_rig()
 {
 	init_cmd();
 	cmd[4] = 0x82; // initiate tuner cycle
+	setr("tune");
 	sendCommand(cmd,0);
-	LOG_INFO("%s", str2hex(cmd.c_str(), 5));
+	seth();
+	LOG_DEBUG("%s", str2hex(cmd.c_str(), 5));
 }
 
 // used to turn tuner ON/OFF
@@ -595,8 +623,10 @@ void RIG_FT1000MP::set_auto_notch(int v)
 	init_cmd();
 	cmd[3] = v ? 0x01 : 0x00;
 	cmd[4] = 0x81; // start antenna tuner
+	setr("tuner on/off");
 	sendCommand(cmd,0);
-	LOG_INFO("%s", str2hex(cmd.c_str(), 5));
+	seth();
+	LOG_DEBUG("%s", str2hex(cmd.c_str(), 5));
 }
 
 int RIG_FT1000MP::get_auto_notch()
@@ -611,7 +641,10 @@ int  RIG_FT1000MP::get_power_out(void)
 	cmd[0] = 0x80;
 	cmd[4] = 0xF7;
 
+	getr("get power out");
 	int ret = sendCommand(cmd);
+	geth();
+
 	if (ret < 5) return 0;
 
 	pwr = (unsigned char)(replystr[ret - 5]);
@@ -623,7 +656,7 @@ int  RIG_FT1000MP::get_power_out(void)
 	else if (pwr <= 130) {pwr /= 130; pwr = 50 * pwr * pwr; }
 	else {pwr /= 177; pwr = 100 * pwr * pwr; }
 
-	LOG_INFO("%s => %d", str2hex(replystr.c_str(), 1), (int)pwr);
+	LOG_DEBUG("%s => %d", str2hex(replystr.c_str(), 1), (int)pwr);
 	return (int)pwr;
 }
 
@@ -633,7 +666,11 @@ int  RIG_FT1000MP::get_smeter(void)
 	init_cmd();
 	cmd[0] = 0x00;
 	cmd[4] = 0xF7;
+
+	getr("get smeter");
 	int ret = waitN(5, 100, "get smeter", HEX);
+	geth();
+
 	if (ret < 5) return 0;
 
 	val = (unsigned char)(replystr[ret-5]);
@@ -641,7 +678,7 @@ int  RIG_FT1000MP::get_smeter(void)
 	else if (val <=154) val = 5 + 45 * (val - 15) / (154 - 15);
 	else val = 50 + 50 * (val - 154.0) / (255.0 - 154.0);
 
-	LOG_INFO("%s => %d",str2hex(replystr.c_str(), 1), (int)val);
+	LOG_DEBUG("%s => %d",str2hex(replystr.c_str(), 1), (int)val);
 
 	return (int)val;
 }
@@ -652,7 +689,11 @@ int  RIG_FT1000MP::get_swr(void)
 	init_cmd();
 	cmd[0] = 0x85;
 	cmd[4] = 0xF7;
+
+	getr("get swr");
 	int ret = waitN(5, 100, "get swr", HEX);
+	geth();
+
 	if (ret < 5) return 0;
 
 	val = (unsigned char)(replystr[ret-5]) - 10;
@@ -661,7 +702,7 @@ int  RIG_FT1000MP::get_swr(void)
 	if (val < 0) val = 0;
 	if (val > 100) val = 100;
 
-	LOG_INFO("%s => %d",str2hex(replystr.c_str(), 1), (int)val);
+	LOG_DEBUG("%s => %d",str2hex(replystr.c_str(), 1), (int)val);
 
 	return (int)val;
 }
@@ -672,11 +713,15 @@ int  RIG_FT1000MP::get_alc(void)
 	init_cmd();
 	cmd[0] = 0x81;
 	cmd[4] = 0xF7;
+
+	getr("get alc");
 	int ret = waitN(5, 100, "get alc", HEX);
+	geth();
+
 	if (ret < 5) return 0;
 
 	val = (unsigned char)(replystr[ret-5]);
-	LOG_INFO("%s => %d",str2hex(replystr.c_str(), 1), val);
+	LOG_DEBUG("%s => %d",str2hex(replystr.c_str(), 1), val);
 
 	return val * 100 / 255;
 }
