@@ -312,9 +312,12 @@ public:
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
 
-		wait();
-		guard_lock service_lock(&mutex_srvc_reqs, "xml rig_get_split");
-		result = progStatus.split;
+		guard_lock serial(&mutex_serial);
+
+		int split_state = selrig->get_split();
+		progStatus.split = split_state;
+		result = split_state;
+xml_trace(2, "rig_get_split ", (split_state ? "ON" : "OFF"));
 	}
 
 	std::string help() { return std::string("returns state of split"); }
@@ -1132,7 +1135,7 @@ public:
 		if (!xcvr_online) return;
 
 		wait();
-		guard_lock service_lock(&mutex_srvc_reqs, "xml rig_get_bwA");
+		guard_lock service_lock(&mutex_srvc_reqs, "xml rig_get_bwB");
 
 		int BW = vfoB.iBW;
 		int mode = vfoB.imode;
@@ -1180,19 +1183,75 @@ public:
 	rig_get_smeter(XmlRpcServer* s) : XmlRpcServerMethod("rig.get_smeter", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-//		if (!xcvr_online || !selrig->has_smeter)
-//			result = (int)(0);
-//		else {
-			result = (int)mval;
-//			guard_lock serial_lock(&mutex_serial);
-//			result = (int)(selrig->get_smeter());
-//		}
+		if (!xcvr_online || !selrig->has_smeter)
+			result = "0";
+		else {
+			guard_lock serial_lock(&mutex_serial);
+			int val = selrig->get_smeter();
+
+			char szMeter[20];
+			snprintf(szMeter, sizeof(szMeter), "%d", val);
+			std::string result_string = szMeter;
+			result = result_string;
+		}
 	}
 
 	std::string help() { return std::string("returns S-meter reading"); }
 
 } rig_get_smeter(&rig_server);
 
+class rig_get_DBM : public XmlRpcServerMethod {
+public:
+	rig_get_DBM(XmlRpcServer* s) : XmlRpcServerMethod("rig.get_DBM", s) {}
+
+	void execute(XmlRpcValue& params, XmlRpcValue& result) {
+		if (!xcvr_online || !selrig->has_smeter)
+			result = "0";
+		else {
+			guard_lock serial_lock(&mutex_serial);
+			int val = selrig->get_smeter();
+			if (val > 50) val = round(-73.0 + (val - 50.0) * 6.0 / 5.0);
+			else          val = round(-127.0 + val * 54.0 / 50.0);
+
+			char szMeter[20];
+			snprintf(szMeter, sizeof(szMeter), "%d", val);
+			std::string result_string = szMeter;
+			result = result_string;
+		}
+	}
+
+	std::string help() { return std::string("returns S-meter in dBm"); }
+
+} rig_get_DBM(&rig_server);
+
+class rig_get_Sunits : public XmlRpcServerMethod {
+public:
+	rig_get_Sunits(XmlRpcServer* s) : XmlRpcServerMethod("rig.get_Sunits", s) {}
+
+	void execute(XmlRpcValue& params, XmlRpcValue& result) {
+		if (!xcvr_online || !selrig->has_smeter)
+			result = "0";
+		else {
+			guard_lock serial_lock(&mutex_serial);
+			int val = selrig->get_smeter();
+
+			char szMeter[20];
+			if (val > 50) {
+				val = round((val - 50.0) * 6.0 / 5.0);
+				snprintf(szMeter, sizeof(szMeter), "S9 + %ddB", val);
+			} else {
+				val = round(val * 9.0 / 50.0);
+				snprintf(szMeter, sizeof(szMeter), "S %d", val);
+			}
+			std::string result_string = szMeter;
+			result = result_string;
+		}
+	}
+
+	std::string help() { return std::string("returns S-meter in S units 0...9...+60"); }
+
+} rig_get_Sunits(&rig_server);
+
 class rig_get_pwrmeter_scale : public XmlRpcServerMethod {
 public:
 	rig_get_pwrmeter_scale(XmlRpcServer* s) : XmlRpcServerMethod("rig.get_pwrmeter_scale", s) {}
@@ -1226,11 +1285,15 @@ public:
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
 		if (!xcvr_online || !selrig->has_power_out)
-			result = (int)(0);
+			result = "0";
 		else {
-			result = (int)pwrval;
-//			guard_lock serial_lock(&mutex_serial);
-//			result = (int)selrig->get_power_out();
+			guard_lock serial_lock(&mutex_serial);
+			int val = selrig->get_power_out();
+			char szmeter[20];
+			snprintf(szmeter, sizeof(szmeter), "%d", val);
+			std::string result_string = szmeter;
+			result = result_string;
+
 		}
 	}
 
@@ -1244,10 +1307,14 @@ public:
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
 		if (!xcvr_online || !selrig->has_swr_control)
-			result = (int)(0);
+			result = "0";
 		else {
 			guard_lock serial_lock(&mutex_serial);
-			result = (int)(selrig->get_swr());
+			int val = selrig->get_swr();
+			char szmeter[20];
+			snprintf(szmeter, sizeof(szmeter), "%d", val);
+			std::string result_string = szmeter;
+			result = result_string;
 		}
 	}
 
@@ -1530,15 +1597,18 @@ public:
 			return;
 		}
 		int state = int(params[0]);
-
-		guard_lock lock(&mutex_srvc_reqs, "xml rig_set_split");
-
-		VFOQUEUE xcvr_split;
-		if (state) xcvr_split.change = sON;
-		else       xcvr_split.change = sOFF;
-		xml_trace(1, (state ? "rig_set_split ON" : "rig_set_split OFF"));
-		srvc_reqs.push(xcvr_split);
-
+		{
+			guard_lock lock(&mutex_srvc_reqs, "xml rig_set_verify_split");
+			VFOQUEUE xcvr_split;
+			if (state) xcvr_split.change = sON;
+			else       xcvr_split.change = sOFF;
+			xml_trace(1, (state ? "rig_set_verify_split ON" : "rig_set_verify_split OFF"));
+			srvc_reqs.push(xcvr_split);
+		}
+		for (int i = 0; i < 50; i++) {
+			if (progStatus.split == state) return;
+			MilliSleep(10);
+		}
 	}
 
 	std::string help() { return std::string("executes vfo split"); }
@@ -1555,15 +1625,18 @@ public:
 			return;
 		}
 		int state = int(params[0]);
-
-		guard_lock lock(&mutex_srvc_reqs, "xml rig_set_verify_split");
-
-		VFOQUEUE xcvr_split;
-		if (state) xcvr_split.change = sON;
-		else       xcvr_split.change = sOFF;
-		xml_trace(1, (state ? "rig_set_verify_split ON" : "rig_set_verify_split OFF"));
-		srvc_reqs.push(xcvr_split);
-
+		{
+			guard_lock lock(&mutex_srvc_reqs, "xml rig_set_verify_split");
+			VFOQUEUE xcvr_split;
+			if (state) xcvr_split.change = sON;
+			else       xcvr_split.change = sOFF;
+			xml_trace(1, (state ? "rig_set_verify_split ON" : "rig_set_verify_split OFF"));
+			srvc_reqs.push(xcvr_split);
+		}
+		for (int i = 0; i < 50; i++) {
+			if (progStatus.split == state) return;
+			MilliSleep(10);
+		}
 	}
 
 	std::string help() { return std::string("sets & verifies vfo split"); }
@@ -2692,11 +2765,13 @@ struct MLIST {
 	{ "rig.get_notch",    "i:n", "return notch value" },
 	{ "rig.get_ptt",      "i:n", "return PTT state" },
 	{ "rig.get_power",    "i:n", "return power level control value" },
-	{ "rig.get_pwrmeter", "i:n", "return PWR out" },
+	{ "rig.get_pwrmeter", "s:n", "return PWR out" },
 	{ "rig.get_pwrmeter_scale", "s:n", "return scale for power meter" },
 	{ "rig.get_pwrmax",   "s:n", "return maximum power available" },
 	{ "rig.get_swrmeter", "s:n", "return SWR out" },
 	{ "rig.get_smeter",   "s:n", "return Smeter" },
+	{ "rig.get_DBM",      "s:n", "return Smeter in dBm" },
+	{ "rig.get_Sunits",   "s:n", "return Smeter in S units" },
 	{ "rig.get_split",    "i:n", "return split state" },
 	{ "rig.get_update",   "s:n", "return update to info" },
 	{ "rig.get_vfo",      "s:n", "return current VFO in Hz" },
@@ -2794,7 +2869,7 @@ void * xml_thread_loop(void *d)
 
 void start_server(int port)
 {
-	XmlRpc::setVerbosity(progStatus.rpc_level);
+//	XmlRpc::setVerbosity(progStatus.rpc_level);
 
 // Create the server socket on the specified port
 	rig_server.bindAndListen(port);
