@@ -978,6 +978,7 @@ void setColors()
 	if (btnNOISE)			btnNOISE->selection_color(btn_lt_color);
 	if (btnAutoNotch)		btnAutoNotch->selection_color(btn_lt_color);
 	if (btnTune)			btnTune->selection_color(btn_lt_color);
+	if (btn_tune_on_off)	btn_tune_on_off->selection_color(btn_lt_color);
 	if (btnPTT)				btnPTT->selection_color(btn_lt_color);
 	if (btnLOCK)			btnLOCK->selection_color(btn_lt_color);
 	if (btnAuxRTS)			btnAuxRTS->selection_color(btn_lt_color);
@@ -985,6 +986,8 @@ void setColors()
 	if (btnSpot)			btnSpot->selection_color(btn_lt_color);
 	if (btn_vox)			btn_vox->selection_color(btn_lt_color);
 	if (btnCompON)			btnCompON->selection_color(btn_lt_color);
+	if (btnPOWER)			btnPOWER->selection_color(btn_lt_color);
+
 	if (btn_tt550_vox)		btn_tt550_vox->selection_color(btn_lt_color);
 	if (btn_tt550_CompON)	btn_tt550_CompON->selection_color(btn_lt_color);
 
