@@ -20,7 +20,7 @@
 
 #include <math.h>
 #include <string>
-
+#include <iostream>
 #include <fstream>
 
 #include <FL/Fl.H>
@@ -63,7 +63,7 @@ bool startXcvrSerial()
 	bypass_serial_thread_loop = true;
 // setup commands for serial port
 	if (progStatus.xcvr_serial_port == "NONE") {
-		bypass_serial_thread_loop = false;
+//		bypass_serial_thread_loop = false;
 		return false;
 	}
 
@@ -165,22 +165,19 @@ void assignReplyStr(string val)
 	selrig->replystr = val;
 }
 
-char replybuff[RXBUFFSIZE+1];
 string respstr;
+#define RXBUFFSIZE 100
 
-int readResponse()
+int readResponse(std::string req1, std::string req2)
 {
 	int numread = 0;
 	respstr.clear();
-	memset(replybuff, 0, RXBUFFSIZE + 1);
 	if (progStatus.use_tcpip)
 		numread = read_from_remote(respstr);
 	else {
-		numread = RigSerial->ReadBuffer(replybuff, RXBUFFSIZE);
-		for (int i = 0; i < numread; respstr += replybuff[i++]);
+		numread = RigSerial->ReadBuffer(respstr, RXBUFFSIZE, req1, req2);
 	}
-	if (numread)
-		LOG_DEBUG("rsp:%3d, %s", numread, str2hex(respstr.c_str(), respstr.length()));
+	LOG_DEBUG("rsp:%3d, %s", numread, str2hex(respstr.c_str(), respstr.length()));
 	return numread;
 }
 
@@ -210,12 +207,14 @@ int sendCommand (string s, int nread, int wait)
 		return readResponse();
 	}
 
-	LOG_DEBUG("cmd:%3d, %s", (int)s.length(), str2hex(s.data(), s.length()));
-
 	if (RigSerial->IsOpen() == false) {
+		LOG_DEBUG("Serial Port not open, cmd:%3d, %s",
+			(int)s.length(), str2hex(s.data(), s.length()));
 		return 0;
 	}
 
+	LOG_DEBUG("cmd:%3d, %s", (int)s.length(), str2hex(s.data(), s.length()));
+
 	RigSerial->FlushBuffer();
 	RigSerial->WriteBuffer(s.c_str(), numwrite);
 
@@ -228,7 +227,9 @@ int sendCommand (string s, int nread, int wait)
 		timeout -= 10;
 		Fl::awake();
 	}
+
 	if (nread == 0) return 0;
+
 	return readResponse();
 }
 
@@ -238,7 +239,7 @@ static char sztimeout_alert[200];
 
 static void show_timeout(void *)
 {
-	fl_alert2("%s",sztimeout_alert);
+	fl_alert2("%s", sztimeout_alert);
 }
 
 bool waitCommand(
@@ -301,6 +302,7 @@ bool waitCommand(
 			snprintf(sztemp, sizeof(sztemp), "%s rcvd in %d msec", info.c_str(), waited);
 			showresp(level, how, sztemp, command, returned);
 			waitcount = 0;
+			RigSerial->failed(-1);
 			return true;
 		}
 		waited += 10;
@@ -315,8 +317,9 @@ bool waitCommand(
 	if (waitcount > 4 && !timeout_alert) {
 		timeout_alert = true;
 		snprintf(sztimeout_alert, sizeof(sztimeout_alert), 
-			"Serial i/o failure\n%s TIME OUT in %d ms",
+			"Serial i/o failure\n%s TIMED OUT in %d ms",
 			command.c_str(), waited);
+			RigSerial->failed(1);
 			Fl::awake(show_timeout);
 	}
 	return false;
